@@ -1,6 +1,6 @@
 import requests, json
 
-root = requests.get('http://10.35.234.245:5000/resource/1')
+root = (requests.get('http://10.35.234.245:5000/resource/1')).json()
 
 # Get list of all services available in amazon lightsail
 def services_list():
@@ -14,8 +14,6 @@ def services_count():
 def service_attributes():
     return(root['products']['BD6CCGKBZGJQSHXD']['attributes'].keys())
 
-def zoya():
-    return 100
    
 
     
